#!/usr/bin/env python
#
#
import sys
import math
import cmath
import random
import numpy as np
import matplotlib.pyplot as plt
import matplotlib.cm as cm
import julia1

def julia_loop(im_width, im_height, xwidth, yheight, xmin, ymin, nitmax):
    julia = np.zeros((im_width, im_height))
    for ix in range(im_width):
        for iy in range(im_height):
            nit = 0
            # Map pixel position to a point in the complex plane
            z = complex(float(ix) / im_width * xwidth + xmin,
                        float(iy) / im_height * yheight + ymin)
            # Do the iterations
            julia[ix,iy] = julia1.julialoop(z,c);
    return julia



if __name__ == '__main__':
    print("Julia set fractal generator\n")
    im_width = 1000
    im_height = 1000
    xmin,xmax = -1.5, 1.5
    xwidth = xmax-xmin
    ymin, ymax = -1.5, 1.5
    yheight = ymax - ymin
    nitmax = 1000
    c = complex(-0.1,0.65)
    zabs_max = 2.0
    title="Julia set fractal generator"
    julia = julia_loop(im_width, im_height, xwidth, yheight, xmin, ymin, nitmax)
    print julia[im_width/2]
    fig, ax = plt.subplots()
    ax.imshow(julia, interpolation='nearest', cmap=cm.hot)
    # Set the tick labels to the coordinates of z0 in the complex plane
    xtick_labels = np.linspace(xmin, xmax, xwidth / 0.5)
    ax.set_xticks([(x-xmin) / xwidth * im_width for x in xtick_labels])
    ax.set_xticklabels(['{:.1f}'.format(xtick) for xtick in xtick_labels])
    ytick_labels = np.linspace(ymin, ymax, yheight / 0.5)
    ax.set_yticks([(y-ymin) / yheight * im_height for y in ytick_labels])
    ax.set_yticklabels(['{:.1f}'.format(ytick) for ytick in ytick_labels])
    plt.savefig('test1.pdf')    

    
